#!/usr/bin/env ruby

# Author: Doug Emery
# Date: 2016-07-01
#
# Description: Take as input a file in the format described in
# `convert_to_csv.rb` and output the contents of each row of the spreadsheet
# as a single string. Thus:
#
# identifier 264-000033803|date 2011-09-07T12:52:12-04:00|creator Christens-Barry, William A.|creator Easton, Roger|...
# identifier 259-000033837|creator Christens-Barry, William A.|creator Easton, Roger|creator Knox, Keith|subject Diary...
# identifier 260-000033839|creator Christens-Barry, William A.|creator Easton, Roger|creator Knox, Keith|subject Diary...
#
# Usage: ruby single_string_dollar_sep.rb all_files-import-40-dol-sep.csv > all_lines.txt

require 'csv'

file = ARGV.shift or fail 'Please provide input csv file'

CSV.foreach file, headers: true, col_sep: '$', quote_char: "\x00" do |row|
  # collection array for the name/value pairs
  ra = []
  row.headers.each do |name|
    # get all the values for the name
    values = row.field name
    # skip if value is blank
    next if values.nil? || values.strip.empty?
    # add a name/value pair for each value
    values.split('|').each { |v| ra << "#{name} #{v}" }
  end
  puts ra.join '|'
end